# Generated by Django 3.1.6 on 2021-02-28 21:54

import _socket
from django.conf import settings
import django.contrib.sites.managers
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('mocca_subject', '0011_auto_20210301_0010'),
    ]

    operations = [
        migrations.CreateModel(
            name='GlucoseBaseline',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('mocca_subject.glucose',),
            managers=[
                ('on_site', django.contrib.sites.managers.CurrentSiteManager()),
                ('objects', edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AddField(
            model_name='glucose',
            name='glucose_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='-', max_length=15, verbose_name='Has the patient had their glucose measured today or since the last visit?'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='historicalglucose',
            name='glucose_performed',
            field=models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], default='-', max_length=15, verbose_name='Has the patient had their glucose measured today or since the last visit?'),
            preserve_default=False,
        ),
        migrations.CreateModel(
            name='HistoricalGlucoseBaseline',
            fields=[
                ('revision', django_revision.revision_field.RevisionField(blank=True, editable=False, help_text='System field. Git repository tag:branch:commit.', max_length=75, null=True, verbose_name='Revision')),
                ('created', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('modified', models.DateTimeField(blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow)),
                ('user_created', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user created')),
                ('user_modified', django_audit_fields.fields.userfield.UserField(blank=True, help_text='Updated by admin.save_model', max_length=50, verbose_name='user modified')),
                ('hostname_created', models.CharField(blank=True, default=_socket.gethostname, help_text='System field. (modified on create only)', max_length=60)),
                ('hostname_modified', django_audit_fields.fields.hostname_modification_field.HostnameModificationField(blank=True, help_text='System field. (modified on every save)', max_length=50)),
                ('device_created', models.CharField(blank=True, max_length=10)),
                ('device_modified', models.CharField(blank=True, max_length=10)),
                ('id', django_audit_fields.fields.uuid_auto_field.UUIDAutoField(blank=True, db_index=True, editable=False, help_text='System auto field. UUID primary key.')),
                ('report_datetime', models.DateTimeField(default=edc_utils.date.get_utcnow, help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.", validators=[edc_protocol.validators.datetime_not_before_study_start, edc_model.models.validators.date.datetime_not_future], verbose_name='Report Date')),
                ('consent_model', models.CharField(editable=False, max_length=50, null=True)),
                ('consent_version', models.CharField(editable=False, max_length=10, null=True)),
                ('crf_status', models.CharField(choices=[('INCOMPLETE', 'Incomplete (some data pending)'), ('COMPLETE', 'Complete')], default='INCOMPLETE', help_text='If some data is still pending, flag this CRF as incomplete', max_length=25, verbose_name='CRF status')),
                ('crf_status_comments', models.TextField(blank=True, help_text='for example, why some data is still pending', null=True, verbose_name='Any comments related to status of this CRF')),
                ('history_id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('glucose_date', models.DateField(blank=True, null=True, validators=[edc_model.models.validators.date.date_not_future])),
                ('glucose_fasted', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, null=True, verbose_name='Had the participant fasted?')),
                ('glucose', models.DecimalField(blank=True, decimal_places=2, max_digits=8, null=True, verbose_name='Glucose result')),
                ('glucose_quantifier', models.CharField(choices=[('N/A', ''), ('=', '='), ('>', '>'), ('>=', '>='), ('<', '<'), ('<=', '<=')], default='N/A', max_length=10)),
                ('glucose_units', models.CharField(choices=[('mg/dL', 'mg/dL'), ('mmol/L', 'mmol/L (millimoles/L)'), ('N/A', 'Not applicable')], default='N/A', max_length=15, verbose_name='Units (glucose)')),
                ('glucose_performed', models.CharField(choices=[('Yes', 'Yes'), ('No', 'No')], max_length=15, verbose_name='Has the patient had their glucose measured today or since the last visit?')),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
                ('site', models.ForeignKey(blank=True, db_constraint=False, editable=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='sites.site')),
                ('subject_visit', models.ForeignKey(blank=True, db_constraint=False, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='+', to='mocca_subject.subjectvisit')),
            ],
            options={
                'verbose_name': 'historical glucose baseline',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 3.1.5 on 2021-01-29 02:56

import edc_model.models.validators.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_ae", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="deathreport",
            name="death_date",
            field=models.DateField(
                null=True,
                validators=[edc_model.models.validators.date.date_not_future],
                verbose_name="Date of Death",
            ),
        ),
        migrations.AddField(
            model_name="historicaldeathreport",
            name="death_date",
            field=models.DateField(
                null=True,
                validators=[edc_model.models.validators.date.date_not_future],
                verbose_name="Date of Death",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="death_as_inpatient",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=5,
                null=True,
                verbose_name="Death as inpatient",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="death_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[edc_model.models.validators.date.datetime_not_future],
                verbose_name="Date and Time of Death",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="death_as_inpatient",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=5,
                null=True,
                verbose_name="Death as inpatient",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="death_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[edc_model.models.validators.date.datetime_not_future],
                verbose_name="Date and Time of Death",
            ),
        ),
    ]



# Generated by Django 3.1.7 on 2021-04-13 16:42

from django.db import migrations, models
import edc_model.models.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0021_auto_20210331_1728'),
    ]

    operations = [
        migrations.AlterField(
            model_name='historicalnextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, validators=[edc_model.models.validators.date.date_is_not_now, edc_model.models.validators.date.date_is_future], verbose_name='Next scheduled routine appointment'),
        ),
        migrations.AlterField(
            model_name='nextappointment',
            name='appt_date',
            field=models.DateField(blank=True, help_text='if applicable.', null=True, validators=[edc_model.models.validators.date.date_is_not_now, edc_model.models.validators.date.date_is_future], verbose_name='Next scheduled routine appointment'),
        ),
    ]



# Generated by Django 3.2.9 on 2021-12-11 15:52

import uuid

import _socket
import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("mocca_subject", "0022_auto_20210413_1942"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="bloodresultslipid",
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="hdl",
            new_name="hdl_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="ldl",
            new_name="ldl_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="trig",
            new_name="trig_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="hdl",
            new_name="hdl_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="ldl",
            new_name="ldl_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="trig",
            new_name="trig_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="chol",
            new_name="chol_value",
        ),
        migrations.RenameField(
            model_name="historicalbloodresultslipid",
            old_name="chol",
            new_name="chol_value",
        ),
        migrations.RenameField(
            model_name="bloodresultslipid",
            old_name="lipid_requisition",
            new_name="requisition",
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="chol_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="chol_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="hdl_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="hdl_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="ldl_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="ldl_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="trig_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="trig_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="chol_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="chol_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="hdl_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="hdl_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="ldl_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="ldl_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="trig_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="trig_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="tracking_identifier",
            field=models.CharField(max_length=32, unique=True),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="tracking_identifier",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="contact_attempts_count",
            field=models.IntegerField(
                blank=True,
                help_text="Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.",
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
                verbose_name="Number of attempts made to contact participantsince the expected appointment date",
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="contact_attempts_count",
            field=models.IntegerField(
                blank=True,
                help_text="Not including pre-appointment reminders. Multiple attempts on the same day count as a single attempt.",
                null=True,
                validators=[django.core.validators.MinValueValidator(1)],
                verbose_name="Number of attempts made to contact participantsince the expected appointment date",
            ),
        ),
    ]



DIABETES_CLINIC = "diabetes_clinic"
HIV_CLINIC = "hiv_clinic"
HIV_COHORT = "hiv_cohort"
HYPERTENSION_CLINIC = "hypertension_clinic"
NCD_CLINIC = "ncd_clinic"
NCD_COHORT = "ncd_cohort"
SYSTEMATIC = "systematic"
SEQUENTIAL = "sequential"
NCD = "ncd"
INTEGRATED = "integrated"
NO_INTERRUPTION = "no_interruption"
SOME_INTERRUPTION = "some_interruption"



# Generated by Django 3.1.6 on 2021-03-01 04:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mocca_subject', '0014_auto_20210301_0507'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='bloodresultsfbc',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'export', 'import'), 'get_latest_by': 'modified', 'ordering': ('-modified', '-created'), 'verbose_name': 'Blood Result: FBC', 'verbose_name_plural': 'Blood Results: FBC'},
        ),
        migrations.AlterModelOptions(
            name='historicalbloodresultsfbc',
            options={'get_latest_by': 'history_date', 'ordering': ('-history_date', '-history_id'), 'verbose_name': 'historical Blood Result: FBC'},
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='chol_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='dm_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='hiv_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='clinicalreviewbaseline',
            name='htn_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='chol_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='dm_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='hiv_test_estimated_datetime',
        ),
        migrations.RemoveField(
            model_name='historicalclinicalreviewbaseline',
            name='htn_test_estimated_datetime',
        ),
        migrations.AddField(
            model_name='clinicalreviewbaseline',
            name='chol_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `chol_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='clinicalreviewbaseline',
            name='dm_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `dm_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='clinicalreviewbaseline',
            name='hiv_test_estimated_date',
            field=models.DateField(blank=True, editable=False, help_text='calculated by the EDC using `hiv_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='clinicalreviewbaseline',
            name='htn_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `htn_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='historicalclinicalreviewbaseline',
            name='chol_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `chol_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='historicalclinicalreviewbaseline',
            name='dm_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `dm_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='historicalclinicalreviewbaseline',
            name='hiv_test_estimated_date',
            field=models.DateField(blank=True, editable=False, help_text='calculated by the EDC using `hiv_test_ago`', null=True),
        ),
        migrations.AddField(
            model_name='historicalclinicalreviewbaseline',
            name='htn_test_estimated_date',
            field=models.DateField(blank=True, help_text='calculated by the EDC using `htn_test_ago`', null=True),
        ),
    ]



from django.conf import settings
from django.db import models
from edc_constants.choices import YES_NO
from edc_constants.constants import NOT_APPLICABLE
from edc_dx_review.model_mixins import (
    InitialReviewModelMixin,
    NcdInitialReviewModelMixin,
)
from edc_model import models as edc_models

from ..choices import CHOL_MANAGEMENT
from ..model_mixins import CrfModelMixin, DiagnosisLocationModelMixin


class CholInitialReview(
    InitialReviewModelMixin,
    DiagnosisLocationModelMixin,
    NcdInitialReviewModelMixin,
    CrfModelMixin,
    edc_models.BaseUuidModel,
):

    ncd_condition_label = "cholesterol"

    subject_visit = models.OneToOneField(
        settings.SUBJECT_VISIT_MODEL,
        on_delete=models.PROTECT,
        related_name="+",
    )

    managed_by = models.CharField(
        verbose_name="How is the patient's cholesterol managed?",
        max_length=25,
        choices=CHOL_MANAGEMENT,
        default=NOT_APPLICABLE,
    )

    chol_performed = models.CharField(
        verbose_name=(
            "Has the patient had their cholesterol measured in the last few months?"
        ),
        max_length=15,
        choices=YES_NO,
    )

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "High Cholesterol Initial Review"
        verbose_name_plural = "High Cholesterol Initial Reviews"



from django.db import models
from django.utils.safestring import mark_safe
from edc_constants.choices import TRUE_FALSE_DONT_KNOW
from edc_model import models as edc_models

from ..choices import HOUSEHOLD_YES_NO_CHOICES
from ..model_mixins import CrfModelMixin


class FamilyHistory(CrfModelMixin, edc_models.BaseUuidModel):
    htn_in_household = models.CharField(
        verbose_name=mark_safe(
            "Do you know if anyone else in your household has <u>high blood pressure</u>?"
        ),
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    dm_in_household = models.CharField(
        verbose_name=mark_safe(
            "Do you know if anyone else in your household has <u>diabetes</u>?"
        ),
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    hiv_in_household = models.CharField(
        verbose_name=mark_safe("Do you know if anyone else in your household has <u>HIV</u>?"),
        max_length=25,
        choices=HOUSEHOLD_YES_NO_CHOICES,
    )

    high_bp_bs_tf = models.CharField(
        verbose_name=mark_safe(
            "High blood pressure and high blood sugar can cause many "
            "illnesses like heart attacks, stroke, kidney failure"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    overweight_tf = models.CharField(
        verbose_name=mark_safe(
            "Being overweight protects from high blood pressure and high blood sugar"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    salty_foods_tf = models.CharField(
        verbose_name=mark_safe("Salty food protects from high blood sugar"),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    excercise_tf = models.CharField(
        verbose_name=mark_safe(
            "Regular exercise is important for people with <u>high blood "
            "pressure</u> or <u>high blood sugar</u> even if they are taking "
            "medicines for these conditions."
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    take_medicine_tf = models.CharField(
        verbose_name=mark_safe(
            "Drugs for <u>blood sugar</u> and <u>blood pressure</u> can make you unwell"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    stop_htn_meds_tf = models.CharField(
        verbose_name=mark_safe(
            "It is best to stop taking <u>blood pressure</u> pills when "
            "you feel better and start pill taking again when you feel sick"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    traditional_htn_tf = models.CharField(
        verbose_name=mark_safe(
            "Herbs and traditional medicine are better for "
            "managing <u>blood pressure</u> than pills and medicines"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    stop_dm_meds_tf = models.CharField(
        verbose_name=mark_safe(
            "It is best to stop taking <u>blood sugar</u> medicines when "
            "you feel better and start pill taking again when you feel sick"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    traditional_dm_tf = models.CharField(
        verbose_name=mark_safe(
            "Herbs and traditional medicine are better for managing "
            "<u>diabetes</u> than pills and medicines"
        ),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    dm_cause_tf = models.CharField(
        verbose_name=mark_safe("Having drinks with sugar (e.g. tea/coffee) causes diabetes"),
        max_length=25,
        choices=TRUE_FALSE_DONT_KNOW,
    )

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "Family History and Knowledge"
        verbose_name_plural = "Family History and Knowledge"



from django.conf import settings
from django.core.management.base import BaseCommand, CommandError

from mocca_screening.import_mocca_register import import_mocca_register


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument(
            "--csvfile",
            default=settings.MOCCA_REGISTER_FILE,
            dest="csvfile",
            help="Specify csv path and name",
        )

        parser.add_argument(
            "--force-delete",
            default=False,
            action="store_true",
            dest="force_delete",
            help="Force delete existing records. Cannot be undone!",
        )

    help = "Import MOCCA register (original)"

    def handle(self, *args, **options):
        try:
            import_mocca_register(
                path=options["csvfile"], force_delete=options["force_delete"]
            )
        except FileNotFoundError as e:
            raise CommandError(f"File not found. Got {e}")



from datetime import datetime

from dateutil.tz.tz import gettz
from django.apps import AppConfig as DjangoAppConfig
from django.conf import settings


class AppConfig(DjangoAppConfig):
    name = "mocca_dashboard"
    admin_site_name = "inte_test_admin"
    include_in_administration_section = False


if settings.APP_NAME == "mocca_dashboard":
    from dateutil.relativedelta import FR, MO, SA, SU, TH, TU, WE
    from edc_facility.apps import AppConfig as BaseEdcFacilityAppConfig
    from edc_identifier.apps import AppConfig as BaseEdcIdentifierAppConfig
    from edc_metadata.apps import AppConfig as BaseEdcMetadataAppConfig
    from edc_protocol.apps import AppConfig as BaseEdcProtocolAppConfig
    from edc_visit_tracking.apps import AppConfig as BaseEdcVisitTrackingAppConfig

    class EdcProtocolAppConfig(BaseEdcProtocolAppConfig):
        protocol = "EDC093"
        protocol_name = "INTE"
        protocol_number = "093"
        protocol_title = ""
        study_open_datetime = datetime(2019, 7, 31, 0, 0, 0, tzinfo=gettz("UTC"))
        study_close_datetime = datetime(2022, 12, 31, 23, 59, 59, tzinfo=gettz("UTC"))

    class EdcFacilityAppConfig(BaseEdcFacilityAppConfig):
        country = "uganda"
        definitions = {
            "7-day-clinic": dict(
                days=[MO, TU, WE, TH, FR, SA, SU],
                slots=[100, 100, 100, 100, 100, 100, 100],
            ),
            "5-day-clinic": dict(days=[MO, TU, WE, TH, FR], slots=[100, 100, 100, 100, 100]),
        }

    class EdcVisitTrackingAppConfig(BaseEdcVisitTrackingAppConfig):
        visit_models = {"mocca_subject": ("subject_visit", "mocca_subject.subjectvisit")}

    class EdcIdentifierAppConfig(BaseEdcIdentifierAppConfig):
        identifier_prefix = "093"

    class EdcMetadataAppConfig(BaseEdcMetadataAppConfig):
        reason_field = {"mocca_subject.subjectvisit": "reason"}



from django.contrib import admin
from django.utils.safestring import mark_safe
from django_audit_fields.admin import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import mocca_subject_admin
from ..forms import DrugRefillCholForm
from ..models import DrugRefillChol
from .modeladmin_mixins import CrfModelAdminMixin


@admin.register(DrugRefillChol, site=mocca_subject_admin)
class DrugRefillCholAdmin(CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin):
    form = DrugRefillCholForm

    additional_instructions = mark_safe(
        '<span style="color:orange">Note: Medications CRF must be completed first.</span>'
    )

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Hypertension Drug Refill Today",
            {
                "fields": (
                    "rx",
                    "rx_other",
                    "rx_modified",
                    "modifications",
                    "modifications_other",
                    "modifications_reason",
                    "modifications_reason_other",
                    "return_in_days",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = ["rx", "modifications", "modifications_reason"]

    radio_fields = {
        "crf_status": admin.VERTICAL,
        "rx_modified": admin.VERTICAL,
    }



from django.contrib import admin
from edc_form_label.form_label_modeladmin_mixin import FormLabelModelAdminMixin
from edc_model_admin import SimpleHistoryAdmin

from ..admin_site import mocca_subject_admin
from ..forms import GlucoseBaselineForm
from ..models import GlucoseBaseline
from .modeladmin_mixins import CrfModelAdminMixin, GlucoseModelAdminMixin


@admin.register(GlucoseBaseline, site=mocca_subject_admin)
class GlucoseBaselineAdmin(
    GlucoseModelAdminMixin, CrfModelAdminMixin, FormLabelModelAdminMixin, SimpleHistoryAdmin
):

    form = GlucoseBaselineForm

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj=obj, **kwargs)
        form = self.replace_label_text(
            form, "since the last visit", "sometime in the past few months"
        )
        return form



# Generated by Django 3.0.9 on 2020-12-03 23:32

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models

import mocca_screening.models.mocca_register_contact


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("mocca_screening", "0006_moccaregistercontact"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="moccaregistercontact",
            managers=[
                ("on_site", edc_sites.models.CurrentSiteManager()),
                ("objects", mocca_screening.models.mocca_register_contact.Manager()),
            ],
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="site",
            field=models.ForeignKey(
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="+",
                to="sites.Site",
            ),
        ),
        migrations.CreateModel(
            name="HistoricalMoccaRegisterContact",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(default=edc_utils.date.get_utcnow),
                ),
                (
                    "contacted",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        default="No",
                        max_length=15,
                    ),
                ),
                (
                    "survival_status",
                    models.CharField(
                        choices=[
                            ("alive", "Alive"),
                            ("dead", "Deceased"),
                            ("unknown", "Unknown"),
                        ],
                        max_length=15,
                        null=True,
                    ),
                ),
                (
                    "willing_to_attend",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")], max_length=15, null=True
                    ),
                ),
                (
                    "call_again",
                    models.CharField(choices=[("Yes", "Yes"), ("No", "No")], max_length=15),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "mocca_register",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="mocca_screening.MoccaRegister",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical MOCCA Patient Register Contact",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 3.0.9 on 2020-12-06 18:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0020_auto_20201206_2110"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalmoccaregistercontact",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_care",
            new_name="care",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_care_facility_location",
            new_name="care_facility_location",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="not_in_care_reason",
            new_name="care_not_in_reason",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="not_in_icc_reason",
            new_name="icc_not_in_reason",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc_since_mocca",
            new_name="icc_since_mocca",
        ),
        migrations.RenameField(
            model_name="historicalsubjectscreening",
            old_name="in_icc_since_mocca_comment",
            new_name="icc_since_mocca_comment",
        ),
        migrations.RenameField(
            model_name="moccaregistercontact",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_care",
            new_name="care",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_care_facility_location",
            new_name="care_facility_location",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="not_in_care_reason",
            new_name="care_not_in_reason",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc",
            new_name="icc",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="not_in_icc_reason",
            new_name="icc_not_in_reason",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc_since_mocca",
            new_name="icc_since_mocca",
        ),
        migrations.RenameField(
            model_name="subjectscreening",
            old_name="in_icc_since_mocca_comment",
            new_name="icc_since_mocca_comment",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectscreening",
            name="comment",
        ),
        migrations.RemoveField(
            model_name="subjectscreening",
            name="comment",
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments related to this patient's care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="care_comment",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="Additional comments related to this patient's care",
            ),
        ),
    ]



from django.contrib import admin
from edc_blood_results.admin import BloodResultsModelAdminMixin
from edc_blood_results.fieldsets import BloodResultFieldset

from ..admin_site import mocca_subject_admin
from ..forms import BloodResultsLipidForm
from ..models import BloodResultsLipid
from .modeladmin_mixins import CrfModelAdmin


@admin.register(BloodResultsLipid, site=mocca_subject_admin)
class BloodResultsLipidAdmin(BloodResultsModelAdminMixin, CrfModelAdmin):
    form = BloodResultsLipidForm
    fieldsets = BloodResultFieldset(
        BloodResultsLipid.lab_panel, model_cls=BloodResultsLipid
    ).fieldsets



from dateutil.relativedelta import relativedelta
from django.test import TestCase, tag
from edc_appointment.constants import INCOMPLETE_APPT
from edc_constants.constants import INCOMPLETE, NO, NOT_APPLICABLE, YES
from edc_utils import get_utcnow
from edc_visit_tracking.constants import UNSCHEDULED
from model_bakery import baker

from mocca_screening.constants import HIV_CLINIC
from mocca_subject.forms.clinical_review_form import ClinicalReviewForm

from ..mocca_test_case_mixin import MoccaTestCaseMixin


class TestClinicalReview(MoccaTestCaseMixin, TestCase):
    def setUp(self):
        super().setUp()
        self.subject_screening = self.get_subject_screening(
            report_datetime=get_utcnow(), clinic_type=HIV_CLINIC
        )
        self.subject_consent = self.get_subject_consent(
            subject_screening=self.subject_screening, clinic_type=HIV_CLINIC
        )

    @tag("cr")
    def test_clinical_review_requires_baseline_and_initial(self):
        subject_visit_baseline = self.get_subject_visit(
            subject_screening=self.subject_screening,
            subject_consent=self.subject_consent,
        )
        subject_visit_baseline.appointment.appt_status = INCOMPLETE_APPT
        subject_visit_baseline.appointment.save()
        subject_visit_baseline.appointment.refresh_from_db()
        subject_visit_baseline.refresh_from_db()

        subject_visit = self.get_next_subject_visit(
            subject_visit=subject_visit_baseline, reason=UNSCHEDULED
        )

        data = {
            "subject_visit": subject_visit,
            "report_datetime": subject_visit.report_datetime,
            "crf_status": INCOMPLETE,
        }
        form = ClinicalReviewForm(data=data)
        form.is_valid()
        self.assertIn("__all__", form._errors)

        # add clinicalreviewbaseline
        baker.make(
            "mocca_subject.clinicalreviewbaseline",
            subject_visit=subject_visit_baseline,
            hiv_test=YES,
            hiv_test_date=get_utcnow() - relativedelta(years=5),
            hiv_dx=YES,
        )
        form = ClinicalReviewForm(data=data)
        form.is_valid()
        self.assertIn("__all__", form._errors)

        # add hivinitialreview
        baker.make(
            "mocca_subject.hivinitialreview",
            subject_visit=subject_visit_baseline,
            dx_date=get_utcnow() - relativedelta(years=5),
            arv_initiation_ago="4y",
        )

        form = ClinicalReviewForm(data=data)
        form.is_valid()
        self.assertNotIn("__all__", form._errors)

    @tag("cr")
    def test_hiv_na_if_diagnosed(self):
        subject_visit_baseline = self.get_subject_visit(
            subject_screening=self.subject_screening,
            subject_consent=self.subject_consent,
        )
        baker.make(
            "mocca_subject.clinicalreviewbaseline",
            subject_visit=subject_visit_baseline,
            hiv_dx=YES,
            hiv_test_ago="5y",
        )

        baker.make(
            "mocca_subject.hivinitialreview",
            subject_visit=subject_visit_baseline,
            dx_ago="5y",
            arv_initiation_ago="4y",
        )

        subject_visit_baseline.appointment.appt_status = INCOMPLETE_APPT
        subject_visit_baseline.appointment.save()
        subject_visit_baseline.appointment.refresh_from_db()
        subject_visit_baseline.refresh_from_db()

        subject_visit = self.get_next_subject_visit(
            subject_visit=subject_visit_baseline, reason=UNSCHEDULED
        )

        data = {
            "subject_visit": subject_visit,
            "report_datetime": subject_visit.report_datetime,
            "crf_status": INCOMPLETE,
        }
        for hiv_test in [YES, NO]:
            with self.subTest():
                data.update(hiv_test=hiv_test)
                form = ClinicalReviewForm(data=data)
                form.is_valid()
                self.assertIn("hiv_test", form._errors)
                self.assertIn("not applicable", form._errors.get("hiv_test")[0])

        data.update(hiv_test=NOT_APPLICABLE)
        form = ClinicalReviewForm(data=data)
        form.is_valid()
        self.assertNotIn("hiv_test", form._errors)



import unittest
from importlib import import_module

from django.test import override_settings, tag
from django.urls import reverse
from django_webtest import WebTest
from edc_auth.auth_objects import AUDITOR, EVERYONE
from edc_auth.auth_updater import AuthUpdater
from edc_constants.constants import ALIVE, DEAD, FEMALE, MALE, NO, NOT_APPLICABLE, YES
from edc_screening.auth_objects import SCREENING
from edc_sites import get_current_country
from model_bakery.baker import make_recipe

from mocca_lists.models import MoccaOriginalSites
from mocca_screening.admin.changelist_buttons import (
    CareStatusButton,
    ScreeningButton,
    SubjectRefusalScreeningButton,
)
from mocca_screening.forms import SubjectScreeningForm
from mocca_screening.forms.mocca_register_form import MoccaRegisterFormValidator
from mocca_screening.models import (
    CareStatus,
    MoccaRegister,
    SubjectRefusalScreening,
    SubjectScreening,
)

from ..mocca_test_case_mixin import MoccaTestCaseMixin


class TestScreening(MoccaTestCaseMixin, WebTest):
    """
    Uganda,Kiswa,KB-0140--1,05-0124,GW,1936,82,Male
    Uganda,Kiswa,KB-0141--1,05-0125,NM,1960,58,Female
    """

    import_randomization_list = False

    def setUp(self):
        super().setUp()
        self.assertEqual("uganda", get_current_country())
        self.mocca_register = MoccaRegister.objects.get(
            mocca_country=get_current_country(), mocca_study_identifier="05-0125"
        )
        self.mocca_register_male = MoccaRegister.objects.get(
            mocca_country=get_current_country(), mocca_study_identifier="05-0124"
        )
        self.mocca_site = MoccaOriginalSites.objects.get(
            name=self.mocca_register.mocca_site.name
        )

    def test_screening_ok(self):
        for mocca_register in [self.mocca_register, self.mocca_register_male]:
            with self.subTest(mocca_register=mocca_register):
                form = SubjectScreeningForm(
                    data=self.get_subject_screening_form_data(mocca_register=mocca_register),
                    instance=None,
                )
                form.is_valid()
                self.assertEqual(form._errors, {})
                form.save()
                self.assertTrue(SubjectScreening.objects.all()[0].eligible)

    def test_screening_no_matching_site(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        sites = {k: v for k, v in self.mocca_sites.items() if v.name != self.mocca_site.name}
        mocca_site = MoccaOriginalSites.objects.get(name=list(sites)[0])
        data.update(mocca_site=mocca_site)
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("mocca_site", form._errors)

    def test_screening_no_matching_study_identifier(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        data.update(mocca_study_identifier="1111111")
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("mocca_study_identifier", form._errors)

    def test_screening_no_matching_gender(self):
        for mocca_register in [self.mocca_register, self.mocca_register_male]:
            with self.subTest(mocca_register=mocca_register):
                data = self.get_subject_screening_form_data(mocca_register)
                data.update(gender=FEMALE if data.get("gender") == MALE else MALE)
                form = SubjectScreeningForm(data=data, instance=None)
                form.is_valid()
                self.assertIn("gender", form._errors)

    def test_screening_no_matching_initials(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        data.update(initials="XX")
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("initials", form._errors)

    def test_screening_no_matching_birth_year(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        data.update(birth_year=1901)
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("birth_year", form._errors)

    def test_screening_invalid_by_age(self):

        data = self.get_subject_screening_form_data(gender=MALE)

        responses = dict(
            age_in_years=300,
        )

        for k, v in responses.items():
            with self.subTest(k=v):
                data.update({k: v})
                form = SubjectScreeningForm(data=data, instance=None)
                form.is_valid()
                self.assertIn("age_in_years", form._errors)

    def test_screening_care_reason(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        data.update(care=NO)
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("care_not_in_reason", form._errors)

    def test_screening_care_facility_location(self):
        data = self.get_subject_screening_form_data(gender=MALE)
        data.update(
            care=NO, care_not_in_reason="blah blah", care_facility_location="somewhere"
        )
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        self.assertIn("care_facility_location", form._errors)

    def screen(self, field, value):
        for gender in [MALE, FEMALE]:
            if field == "pregnant" and gender == MALE:
                continue
            data = self.get_subject_screening_form_data(gender=gender)
            data.update({field: value})
            if field == "care":
                data.update(
                    care_not_in_reason="blah blah",
                    care_facility_location=NOT_APPLICABLE,
                    icc=NOT_APPLICABLE,
                    icc_since_mocca=NO,
                )
            form = SubjectScreeningForm(data=data, instance=None)
            form.is_valid()
            self.assertEqual(form._errors, {})
            form.save()
            self.assertFalse(
                SubjectScreening.objects.get(
                    mocca_study_identifier=data.get("mocca_study_identifier")
                ).eligible
            )

    def test_screening_ineligible_unwilling(self):
        self.screen("willing_to_consent", NO)

    def test_screening_ineligible_requires_acute_care(self):
        self.screen("requires_acute_care", YES)

    def test_screening_ineligible_care(self):
        self.screen("care", NO)

    def test_screening_ineligible_pregnant(self):
        self.screen("pregnant", YES)

    def test_screening_unsuitable(self):

        data = self.get_subject_screening_form_data(gender=FEMALE)
        data.update(unsuitable_for_study=YES)
        form = SubjectScreeningForm(data=data, instance=None)
        form.is_valid()
        form.save()
        self.assertFalse(
            SubjectScreening.objects.get(
                mocca_study_identifier=data.get("mocca_study_identifier")
            ).eligible
        )

    def test_mocca_register_validator_ok(self):

        cleaned_data = {
            "report_datetime": self.mocca_register.report_datetime,
            "screening_identifier": self.mocca_register.screening_identifier,
            "mocca_study_identifier": self.mocca_register.mocca_study_identifier,
            "mocca_country": "uganda",
            "mocca_site": self.mocca_register.mocca_site,
            "initials": self.mocca_register.initials,
            "gender": self.mocca_register.gender,
            "age_in_years": self.mocca_register.age_in_years,
            "birth_year": self.mocca_register.birth_year,
            "survival_status": DEAD,
            "call": YES,
            "screen_now": NO,
        }
        form_validator = MoccaRegisterFormValidator(
            cleaned_data=cleaned_data, instance=self.mocca_register
        )
        form_validator.validate()
        self.assertDictEqual({}, form_validator._errors)

    def test_mocca_register_validator_deceased(self):

        cleaned_data = {
            "report_datetime": self.mocca_register.report_datetime,
            "screening_identifier": self.mocca_register.screening_identifier,
            "mocca_study_identifier": self.mocca_register.mocca_study_identifier,
            "mocca_country": "uganda",
            "mocca_site": self.mocca_register.mocca_site,
            "initials": self.mocca_register.initials,
            "gender": self.mocca_register.gender,
            "age_in_years": self.mocca_register.age_in_years,
            "birth_year": self.mocca_register.birth_year,
            "survival_status": DEAD,
            "call": YES,
            "screen_now": YES,
        }
        form_validator = MoccaRegisterFormValidator(
            cleaned_data=cleaned_data, instance=self.mocca_register
        )
        form_validator.validate()
        self.assertDictEqual({}, form_validator._errors)

    @unittest.skip("Skipping webtest...")
    @tag("webtest")
    def test_mocca_register_changelist_buttons(self):

        button = ScreeningButton(
            mocca_register=self.mocca_register, changelist_url_name=self.changelist_url_name
        )
        response = self.app.get(button.add_url, user=self.user, status=200)
        self.assertIn(f"Add {SubjectScreening._meta.verbose_name}", response)

        button = SubjectRefusalScreeningButton(
            mocca_register=self.mocca_register, changelist_url_name=self.changelist_url_name
        )
        response = self.app.get(button.add_url, user=self.user, status=200)
        self.assertIn(f"Add {SubjectRefusalScreening._meta.verbose_name}", response)

        button = CareStatusButton(
            mocca_register=self.mocca_register, changelist_url_name=self.changelist_url_name
        )
        response = self.app.get(button.add_url, user=self.user, status=200)
        self.assertIn(f"Add {CareStatus._meta.verbose_name}", response)

    @unittest.skip("Skipping webtest...")
    @tag("webtest")
    @override_settings(
        EDC_AUTH_SKIP_SITE_AUTHS=False,
        EDC_AUTH_SKIP_AUTH_UPDATER=False,
    )
    def test_mocca_register_changelist(self):
        import_module("mocca_auth.auths")
        AuthUpdater(verbose=True)

        make_recipe("mocca_screening.moccaregistercontact", mocca_register=self.mocca_register)
        mocca_register_contact = make_recipe(
            "mocca_screening.moccaregistercontact", mocca_register=self.mocca_register
        )

        self.login(superuser=False, groups=[EVERYONE, AUDITOR, SCREENING])

        change_list_url = reverse(self.changelist_url_name)
        change_list_url = f"{change_list_url}?q={self.mocca_register.mocca_study_identifier}"
        screening_add_url = reverse(
            "mocca_screening_admin:mocca_screening_subjectscreening_add"
        )
        refusal_add_url = reverse(
            "mocca_screening_admin:mocca_screening_subjectrefusalscreening_add"
        )

        # Test screening and refusal buttons are shown
        # (for alive, don't call again, willing to attend)
        mocca_register_contact.survival_status = ALIVE
        mocca_register_contact.call = NO
        mocca_register_contact.willing_to_attend = YES
        mocca_register_contact.save()
        self.assertTrue(mocca_register_contact.call == NO)
        self.assertTrue(mocca_register_contact.willing_to_attend == YES)
        self.assertTrue(mocca_register_contact.survival_status == ALIVE)
        response = self.app.get(change_list_url, user=self.user, status=200)
        self.assertIn(self.mocca_register.mocca_study_identifier, response)
        self.assertIn(screening_add_url, response)
        self.assertIn(refusal_add_url, response)

        # Test screening button hidden, refusal button shown
        # (for alive, don't call again, NOT willing to attend)
        mocca_register_contact.willing_to_attend = NO
        mocca_register_contact.save()
        self.assertTrue(mocca_register_contact.willing_to_attend == NO)
        response = self.app.get(change_list_url, user=self.user, status=200)
        self.assertIn(self.mocca_register.mocca_study_identifier, response)
        self.assertNotIn(screening_add_url, response)
        self.assertIn(refusal_add_url, response)

        # Test neither the refusal nor the screening button shown
        # (for deceased status)
        mocca_register_contact.willing_to_attend = NOT_APPLICABLE
        mocca_register_contact.survival_status = DEAD
        mocca_register_contact.save()
        self.assertTrue(mocca_register_contact.survival_status == DEAD)
        response = self.app.get(change_list_url, user=self.user, status=200)
        self.assertNotIn(screening_add_url, response)
        self.assertNotIn(refusal_add_url, response)

    @unittest.skip("Skipping webtest...")
    @tag("webtest")
    def test_mocca_register_changelist_without_contact(self):

        self.login(superuser=False, groups=[EVERYONE, AUDITOR, SCREENING])
        change_list_url = reverse(
            "mocca_screening_admin:mocca_screening_moccaregister_changelist"
        )
        change_list_url = f"{change_list_url}?q={self.mocca_register.mocca_study_identifier}"
        self.app.get(change_list_url, user=self.user, status=200)



from .autocomplete_models import Rx
from .blood_results_lipid import BloodResultsLipid
from .cd4_result import Cd4Result
from .chol_initial_review import CholInitialReview
from .chol_medication_adherence import CholMedicationAdherence
from .chol_review import CholReview
from .clinical_review import ClinicalReview
from .clinical_review_baseline import ClinicalReviewBaseline
from .complications_baseline import ComplicationsBaseline
from .complications_followup import ComplicationsFollowup
from .dm_initial_review import DmInitialReview
from .dm_medication_adherence import DmMedicationAdherence
from .dm_review import DmReview
from .drug_refill_chol import DrugRefillChol
from .drug_refill_dm import DrugRefillDm
from .drug_refill_hiv import DrugRefillHiv
from .drug_refill_htn import DrugRefillHtn
from .family_history import FamilyHistory
from .glucose_baseline import GlucoseBaseline
from .glucose_followup import GlucoseFollowup
from .hiv_initial_review import HivInitialReview
from .hiv_medication_adherence import HivMedicationAdherence
from .hiv_review import HivReview
from .htn_initial_review import HtnInitialReview
from .htn_medication_adherence import HtnMedicationAdherence
from .htn_review import HtnReview
from .indicators import Indicators
from .investigations import Investigations
from .medications import Medications
from .next_appointment import NextAppointment
from .other_baseline_data import OtherBaselineData
from .patient_health import PatientHealth
from .subject_requisition import SubjectRequisition
from .subject_visit import SubjectVisit
from .subject_visit_missed import SubjectVisitMissed
from .viral_load_result import ViralLoadResult



# Generated by Django 3.2.9 on 2022-01-09 14:17

import _socket
from django.conf import settings
import django.contrib.sites.managers
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_model.models.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("mocca_subject", "0026_auto_20220109_1705"),
    ]

    operations = [
        migrations.CreateModel(
            name="GlucoseFollowup",
            fields=[],
            options={
                "verbose_name": "Glucose: Followup",
                "verbose_name_plural": "Glucose: Followup",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("mocca_subject.glucose",),
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AlterModelOptions(
            name="glucose",
            options={
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Glucose",
                "verbose_name_plural": "Glucose",
            },
        ),
        migrations.AlterModelOptions(
            name="historicalglucose",
            options={
                "get_latest_by": "history_date",
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Glucose",
            },
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="glucose",
            new_name="glucose_value",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="glucose",
            new_name="glucose_value",
        ),
        migrations.RenameField(
            model_name="historicalglucosebaseline",
            old_name="glucose",
            new_name="glucose_value",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="glucose",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.RenameField(
            model_name="historicalglucosebaseline",
            old_name="glucose_assay_datetime",
            new_name="assay_datetime",
        ),
        migrations.RenameField(
            model_name="historicalglucosebaseline",
            old_name="glucose_requisition",
            new_name="requisition",
        ),
        migrations.AddField(
            model_name="glucose",
            name="glucose_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="glucose",
            name="glucose_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="glucose_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucose",
            name="glucose_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalglucosebaseline",
            name="glucose_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucosebaseline",
            name="glucose_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="fasting",
            field=models.CharField(
                choices=[("fasting", "Fasting"), ("non_fasting", "Non-fasting")],
                max_length=25,
                null=True,
                verbose_name="Was this fasting or non-fasting?",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="fasting",
            field=models.CharField(
                choices=[("fasting", "Fasting"), ("non_fasting", "Non-fasting")],
                max_length=25,
                null=True,
                verbose_name="Was this fasting or non-fasting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosebaseline",
            name="fasting",
            field=models.CharField(
                choices=[("fasting", "Fasting"), ("non_fasting", "Non-fasting")],
                max_length=25,
                null=True,
                verbose_name="Was this fasting or non-fasting?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosebaseline",
            name="glucose_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosebaseline",
            name="glucose_units",
            field=models.CharField(
                blank=True,
                choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.CreateModel(
            name="HistoricalGlucoseFollowup",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.models.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default="INCOMPLETE",
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "glucose_units",
                    models.CharField(
                        blank=True,
                        choices=[("mg/dL", "mg/dL"), ("mmol/L", "mmol/L (millimoles/L)")],
                        max_length=15,
                        null=True,
                        verbose_name="units",
                    ),
                ),
                (
                    "glucose_abnormal",
                    models.CharField(
                        blank=True,
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        null=True,
                        verbose_name="abnormal",
                    ),
                ),
                (
                    "glucose_reportable",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("N/A", "Not applicable"),
                            ("3", "Yes, grade 3"),
                            ("4", "Yes, grade 4"),
                            ("No", "Not reportable"),
                            ("Already reported", "Already reported"),
                            ("present_at_baseline", "Present at baseline"),
                        ],
                        max_length=25,
                        null=True,
                        verbose_name="reportable",
                    ),
                ),
                (
                    "glucose_grade",
                    models.IntegerField(
                        blank=True,
                        choices=[
                            (0, "Not graded"),
                            (1, "Grade 1"),
                            (2, "Grade 2"),
                            (3, "Grade 3"),
                            (4, "Grade 4"),
                            (5, "Grade 5"),
                        ],
                        null=True,
                        verbose_name="Grade",
                    ),
                ),
                (
                    "glucose_grade_description",
                    models.CharField(
                        blank=True, max_length=250, null=True, verbose_name="Grade description"
                    ),
                ),
                (
                    "is_poc",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Was a point-of-care test used?",
                    ),
                ),
                (
                    "fasting",
                    models.CharField(
                        choices=[("fasting", "Fasting"), ("non_fasting", "Non-fasting")],
                        max_length=25,
                        null=True,
                        verbose_name="Was this fasting or non-fasting?",
                    ),
                ),
                (
                    "glucose_performed",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Has the patient had their glucose measured today or since the last visit?",
                    ),
                ),
                (
                    "glucose_date",
                    models.DateField(
                        blank=True,
                        null=True,
                        validators=[edc_model.models.validators.date.date_not_future],
                    ),
                ),
                (
                    "glucose_fasted",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Has the participant fasted?",
                    ),
                ),
                (
                    "glucose_value",
                    models.DecimalField(
                        blank=True,
                        decimal_places=2,
                        max_digits=8,
                        null=True,
                        verbose_name="Glucose result",
                    ),
                ),
                (
                    "glucose_quantifier",
                    models.CharField(
                        blank=True,
                        choices=[
                            ("=", "="),
                            (">", ">"),
                            (">=", ">="),
                            ("<", "<"),
                            ("<=", "<="),
                        ],
                        default="=",
                        max_length=10,
                        null=True,
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="mocca_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Glucose: Followup",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



from django import forms
from edc_adverse_event.forms import DeathReportModelFormMixin

from ..models import DeathReport


class DeathReportForm(DeathReportModelFormMixin, forms.ModelForm):
    class Meta:
        model = DeathReport
        fields = "__all__"



from edc_reference import site_reference_configs

site_reference_configs.register_from_visit_schedule(
    visit_models={"edc_appointment.appointment": "mocca_subject.subjectvisit"}
)

configs = {
    "mocca_subject.clinicalreviewbaseline": [
        "hiv_test",
        "dm_test",
        "htn_test",
        "chol_test",
        "hiv_dx",
        "dm_dx",
        "htn_dx",
        "chol_dx",
    ],
    "mocca_subject.clinicalreview": [
        "hiv_test",
        "dm_test",
        "htn_test",
        "chol_test",
        "hiv_dx",
        "dm_dx",
        "htn_dx",
        "chol_dx",
        "complications",
    ],
    "mocca_subject.medications": ["refill_hiv", "refill_dm", "refill_htn", "refill_chol"],
}

for reference_name, fields in configs.items():
    site_reference_configs.add_fields_to_config(name=reference_name, fields=fields)



# Generated by Django 3.0.9 on 2020-12-06 18:10

import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0019_auto_20201205_1834"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="death_date",
            field=models.DateField(blank=True, null=True, verbose_name="Date of death"),
        ),
        migrations.AddField(
            model_name="historicalmoccaregistercontact",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Additioanl comments"),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_care",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                null=True,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_care_facility_location",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either integrated or vertical",
                max_length=25,
                null=True,
                verbose_name="Does the patient receive care in this facility",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc_since_mocca",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("partially", "Partially"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Has the patient received regular integrated care since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="in_icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="not_in_care_reason",
            field=models.CharField(
                blank=True,
                max_length=25,
                null=True,
                verbose_name="If not in care, why?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="not_in_icc_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                ],
                max_length=25,
                null=True,
                verbose_name="If not integrated care, why not?",
            ),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="death_date",
            field=models.DateField(blank=True, null=True, verbose_name="Date of death"),
        ),
        migrations.AddField(
            model_name="moccaregistercontact",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Additioanl comments"),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_care",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                null=True,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_care_facility_location",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either integrated or vertical",
                max_length=25,
                null=True,
                verbose_name="Does the patient receive care in this facility",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Either at this facility or elsewhere",
                max_length=25,
                null=True,
                verbose_name="Does the patient currently receive regular integrated care",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc_since_mocca",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("partially", "Partially"), ("No", "No")],
                max_length=25,
                null=True,
                verbose_name="Has the patient received regular integrated care since the leaving the MOCCA (orig) trial until now?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="in_icc_since_mocca_comment",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="not_in_care_reason",
            field=models.CharField(
                blank=True,
                max_length=25,
                null=True,
                verbose_name="If not in care, why?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="not_in_icc_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    (
                        "icc_not_available",
                        "ICC not available (or closed) in this facility",
                    ),
                    ("moved", "Moved out of area"),
                    (
                        "dont_want",
                        "Personally chose not to continue with integrated care",
                    ),
                    (
                        "advised_to_vertical",
                        "Healthcare staff asked patient to return to vertical care",
                    ),
                    ("referred_out", "Referred to another facility without an ICC"),
                ],
                max_length=25,
                null=True,
                verbose_name="If not integrated care, why not?",
            ),
        ),
    ]



# Generated by Django 3.0.9 on 2020-11-17 19:21

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="ArvDrugs",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Arv Drugs",
                "verbose_name_plural": "Arv Drugs",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ArvRegimens",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "ARV Regimens",
                "verbose_name_plural": "ARV Regimens",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ClinicServices",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Clinic Services",
                "verbose_name_plural": "Clinic Services",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="Conditions",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Conditions",
                "verbose_name_plural": "Conditions",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DmTreatments",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Diabetes Treatments",
                "verbose_name_plural": "Diabetes Treatments",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="DrugPaySources",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Drug Payment Sources",
                "verbose_name_plural": "Drug Payment Sources",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HealthServices",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Health Services",
                "verbose_name_plural": "Health Services",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="HtnTreatments",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Hypertension Treatments",
                "verbose_name_plural": "Hypertension Treatments",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="MoccaOriginalSites",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "MOCCA Original Site",
                "verbose_name_plural": "MOCCA Original Sites",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="NonAdherenceReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "NonAdherence Reasons",
                "verbose_name_plural": "NonAdherence Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="OffstudyReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Offstudy Reasons",
                "verbose_name_plural": "Offstudy Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="ReasonsForTesting",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Reasons for Testing",
                "verbose_name_plural": "Reasons for Testing",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RefillConditions",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Refill Conditions",
                "verbose_name_plural": "Refill Conditions",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RxModificationReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Treatment Modification Reasons",
                "verbose_name_plural": "Treatment Modification Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="RxModifications",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Treatment Modifications",
                "verbose_name_plural": "Treatment Modifications",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="SubjectVisitMissedReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Subject Missed Visit Reasons",
                "verbose_name_plural": "Subject Missed Visit Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="TransportChoices",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Transport Choices",
                "verbose_name_plural": "Transport Choices",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.CreateModel(
            name="VisitReasons",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        help_text="This is the stored value, required",
                        max_length=250,
                        unique=True,
                        verbose_name="Stored value",
                    ),
                ),
                (
                    "display_name",
                    models.CharField(
                        db_index=True,
                        help_text="(suggest 40 characters max.)",
                        max_length=250,
                        unique=True,
                        verbose_name="Name",
                    ),
                ),
                (
                    "display_index",
                    models.IntegerField(
                        db_index=True,
                        default=0,
                        help_text="Index to control display order if not alphabetical, not required",
                        verbose_name="display index",
                    ),
                ),
                (
                    "field_name",
                    models.CharField(
                        blank=True,
                        editable=False,
                        help_text="Not required",
                        max_length=25,
                        null=True,
                    ),
                ),
                (
                    "version",
                    models.CharField(default="1.0", editable=False, max_length=35),
                ),
            ],
            options={
                "verbose_name": "Visit Reasons",
                "verbose_name_plural": "Visit Reasons",
                "ordering": ["display_index", "display_name"],
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
            },
        ),
        migrations.AddIndex(
            model_name="visitreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_1da0dd_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="transportchoices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_1d4d38_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectvisitmissedreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_869c94_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodifications",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_a1aba9_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="rxmodificationreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_d51cdb_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="refillconditions",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_fe820e_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="reasonsfortesting",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_6294e5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offstudyreasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_8d0633_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="nonadherencereasons",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_0061b6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="moccaoriginalsites",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_d0c4f8_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="htntreatments",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_1a87a2_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="healthservices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_170f45_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="drugpaysources",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_c04517_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="dmtreatments",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_c5f2e5_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="conditions",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_a2936a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="clinicservices",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_a5f261_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvregimens",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_e889e6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="arvdrugs",
            index=models.Index(
                fields=["id", "display_name", "display_index"],
                name="mocca_lists_id_eda664_idx",
            ),
        ),
    ]



from django.core.exceptions import ObjectDoesNotExist
from django.db.models.signals import post_delete, post_save
from django.dispatch import receiver
from edc_constants.constants import NO, YES

from .mocca_register_contact import MoccaRegisterContact
from .subject_refusal import SubjectRefusal
from .subject_refusal_screening import SubjectRefusalScreening
from .subject_screening import SubjectScreening


@receiver(
    post_save,
    weak=False,
    sender=SubjectScreening,
    dispatch_uid="subject_screening_on_post_save",
)
def subject_screening_on_post_save(sender, instance, raw, created, **kwargs):
    """Updates `mocca_register` patient screened and do not call"""
    if not raw:
        instance.mocca_register.screening_identifier = instance.screening_identifier
        instance.mocca_register.call = NO
        instance.mocca_register.save(update_fields=["call", "screening_identifier"])


@receiver(
    post_save,
    weak=False,
    sender=SubjectRefusalScreening,
    dispatch_uid="subject_refusal_screening_on_post_save",
)
def subject_refusal_screening_on_post_save(sender, instance, raw, created, **kwargs):
    """Updates `mocca_register` patient refused before screening and do not call"""
    if not raw:
        instance.mocca_register.call = NO
        instance.mocca_register.save(update_fields=["call"])


@receiver(
    post_delete,
    weak=False,
    sender=SubjectRefusalScreening,
    dispatch_uid="subject_refusal_screening_on_post_delete",
)
def subject_refusal_screening_on_post_delete(sender, instance, using, **kwargs):
    """Resets `mocca_register` patient `call`"""
    instance.mocca_register.call = YES
    instance.mocca_register.save(update_fields=["call"])


@receiver(
    post_save,
    weak=False,
    sender=MoccaRegisterContact,
    dispatch_uid="mocca_register_contact_on_post_save",
)
def mocca_register_contact_on_post_save(sender, instance, raw, created, **kwargs):
    if not raw:
        qs = sender.objects.filter(mocca_register=instance.mocca_register)
        instance.mocca_register.contact_attempts = qs.count()
        last_obj = qs.last()
        instance.mocca_register.call = last_obj.call_again
        instance.mocca_register.date_last_called = last_obj.report_datetime.date()
        if last_obj.next_appt_date:
            instance.mocca_register.next_appt_date = last_obj.next_appt_date
        if instance.mocca_register.screening_identifier:
            instance.mocca_register.call = NO
        instance.mocca_register.save(
            update_fields=[
                "call",
                "contact_attempts",
                "date_last_called",
                "next_appt_date",
            ]
        )


@receiver(
    post_save,
    weak=False,
    sender=SubjectRefusal,
    dispatch_uid="subject_refusal_on_post_save",
)
def subject_refusal_on_post_save(sender, instance, raw, created, **kwargs):
    """Updates `refused` field on SubjectScreening"""
    if not raw:
        try:
            obj = SubjectScreening.objects.get(
                screening_identifier=instance.screening_identifier
            )
        except ObjectDoesNotExist:
            pass
        else:
            obj.refused = True
            obj.save(update_fields=["refused"])


@receiver(
    post_delete,
    weak=False,
    sender=SubjectRefusal,
    dispatch_uid="subject_refusal_on_post_delete",
)
def subject_refusal_on_post_delete(sender, instance, using, **kwargs):
    """Updates/Resets subject screening."""
    try:
        obj = SubjectScreening.objects.get(screening_identifier=instance.screening_identifier)
    except ObjectDoesNotExist:
        pass
    else:
        obj.refused = False
        obj.save(update_fields=["refused"])



from edc_sites import get_current_country


class Site:
    def __init__(self, name, title, site_id, enrolled, regex, country):
        self.name = name
        self.title = title
        self.site_id = site_id
        self.enrolled = enrolled
        self.regex = regex
        self.country = country

    def __repr__(self):
        return f"{self.__class__.__name__}(`{self.name}`)"

    def __str__(self):
        return self.name


sites = {
    "amana": Site("amana", "Amana", 1, 237, r"^060[0-9]{3}", "tanzania"),
    "bunju": Site("bunju", "Bunju", 2, 118, r"^080[0-9]{3}", "tanzania"),
    "hindu_mandal": Site("hindu_mandal", "Hindu Mandal", 3, 223, r"^070[0-9]{3}", "tanzania"),
    "mkuranga": Site("mkuranga", "Mkuranga", 4, 117, r"^100[0-9]{3}", "tanzania"),
    "mwananyamala": Site("mwananyamala", "Mwananyamala", 5, 117, r"^090[0-9]{3}", "tanzania"),
    "kisugu": Site("kisugu", "Kisugu", 6, 179, r"^04\-0[0-9]{3}", "uganda"),
    "kiswa": Site("kiswa", "Kiswa", 7, 191, r"^05\-0[0-9]{3}", "uganda"),
    "mulago": Site("mulago", "Mulago", 8, 257, r"^01\-0[0-9]{3}", "uganda"),
    "ndejje": Site("ndejje", "Ndejje", 9, 247, r"^03\-0[0-9]{3}", "uganda"),
    "wakiso": Site("wakiso", "Wakiso", 10, 225, r"^02\-0[0-9]{3}", "uganda"),
}


def get_mocca_sites_by_country(country=None):
    return {k: v for k, v in sites.items() if v.country == country}


def get_mocca_site_limited_to():
    return {
        "name__in": [
            site.name for site in sites.values() if site.country == get_current_country()
        ]
    }



# Generated by Django 3.0.9 on 2020-12-14 23:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("mocca_screening", "0001_squashed_0024_auto_20201206_2352"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="-",
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="requires_acute_care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="-",
                max_length=25,
                verbose_name="Does the patient require acute care including in-patient admission",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="pregnant",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("N/A", "Not Applicable: e.g. male"),
                ],
                default="_",
                max_length=15,
                verbose_name="Is the patient pregnant?",
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="requires_acute_care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="-",
                max_length=25,
                verbose_name="Does the patient require acute care including in-patient admission",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Is the patient in care?",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="care",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("unknown", "Unknown")],
                max_length=25,
                verbose_name="Is the patient in care?",
            ),
        ),
    ]



from edc_model import models as edc_models

from ..model_mixins import CrfModelMixin, MedicationAdherenceModelMixin


class HivMedicationAdherence(
    MedicationAdherenceModelMixin,
    CrfModelMixin,
    edc_models.BaseUuidModel,
):

    condition_label = "HIV"

    class Meta(CrfModelMixin.Meta, edc_models.BaseUuidModel.Meta):
        verbose_name = "HIV Medication Adherence"
        verbose_name_plural = "HIV Medication Adherence"
